# tfiers-py

My IPython notebook setup and my Matplotlib style.

Used in notebooks as:
```
from tfiers.nb import *
```
This will import `numpy` as `np`, setup autoreload, set the mpl style, etc. 

## Installation

```
pip install tfiers
```
This will get you the

[![Latest release on PyPI](https://img.shields.io/pypi/v/tfiers.svg?label=latest%20release%20on%20PyPI:)](https://pypi.python.org/pypi/tfiers/)

(Update an existing installation with `pip install -U tfiers`).
